unit NZCSFunct;

interface

{$I NZCS.INC}

uses
   SysUtils, Windows, Messages, Classes, Graphics, Controls,
   Forms, Dialogs, ExtCtrls, Buttons, StdCtrls, Registry;

   function AppPath: string;
   function RightStr(Str: string; Spaces: Integer): string;
   function LeftStr(Str: string; Spaces: Integer): string;
   Function Mid(Str: String; Start: Integer; Finish: Integer{$IFDEF NZCS_COMPILER_3_UP} = MaxInt{$ENDIF}): String;

   function AsChar(Value: String): Char;
   function GetChar(Value: String; index: smallint): Char;


   procedure MsgWarn(Msg: STRING); {Shows a Message and raises an exception}
   function MsgYesNo(Msg: string): Boolean;

   function GetRegStrValue(RootKeyType: HKEY; Key, Value: String): string;
   procedure SetRegStrValue(RootKeyType: HKEY; Key, ValueKey, Value: String);

   function FindWindowsDir :STRING;
   
implementation

function AppPath: string; {Appliction Exe Path}
var
   TmpPath: string;
begin
   TmpPath := ExtractFilePath(Application.Exename);
   if RightStr(TmpPath, 1) <> '\' then
      TmpPath := TmpPath + '\';
   Result := TmpPath;
end;

{Like Visual Basics Left$ - returns the start OF a STRING TO the number OF spaces sent}
function LeftStr(Str: string; Spaces: Integer): string;
begin
   Result := Copy(Str, 1, Spaces);
end;

{Like Visual Basics Right$ - returns the END OF a STRING back so many spaces}
function RightStr(Str: string; Spaces: Integer): string;
begin
   Spaces := Spaces - 1;
   Result := Copy(Str, length(Str) - Spaces, Length(Str));
end;

Function Mid(Str: String; Start: Integer; Finish: Integer{$IFDEF NZCS_COMPILER_3_UP} = MaxInt{$ENDIF}): String;
begin
   result := Copy(Str, Start, Finish);
end;

function AsChar(Value: String): Char;
begin
  result := GetChar(Value,1);
end;

function GetChar(Value: String; index: smallint): Char;
begin
   if Length(Value) < index then result := #0 else Result := Value[index];
end;

procedure MsgWarn(Msg: STRING); {Shows a Message and raises an exception}
begin
   Messagedlg(msg, mtWarning, [MbOK], 0);
   Abort;
end;

function MsgYesNo(Msg: STRING): Boolean;
begin
   Result := True;
   if Messagedlg(msg, MtConfirmation, [MbYes, MbNo], 0) = MrNo then
      Result := False;
end;

function GetRegStrValue(RootKeyType: HKEY; Key, Value: String): string;
var
   Registry: TRegistry;
begin
   Result := '';
   Registry := TRegistry.Create;
   try
      Registry.RootKey  := RootKeyType;
      if Registry.OpenKey(Key,False) then begin
         Result := Registry.ReadString(Value);
         Registry.CloseKey;
      end;
   finally
      Registry.Free;
   end;
end;

procedure SetRegStrValue(RootKeyType: HKEY; Key, ValueKey, Value: String);
var
   Registry: TRegistry;
begin
   Registry := TRegistry.Create;
   try
      Registry.RootKey  := RootKeyType;
      if Registry.OpenKey(Key,True) then begin
         Registry.WriteString(ValueKey, Value);
         Registry.CloseKey;
      end;
   finally
      Registry.Free;
   end;
end;

function FindWindowsDir :STRING;
var
   Buffer: PChar;
   Size: Word;
   x: integer;
   WinDir: string;
begin
   Size := 200;
   Inc(Size);
   GetMem(Buffer, Size);           {Creates Buffer dynamic variable}
   x := GetWindowsDirectory(Buffer, Size);
   WinDir := copy(StrPas(Buffer),1,x); {Converts Buffer to a Pascal-style STRING}
   if copy(windir,x - 1, x) <> '\' then
      windir := windir + '\';
   FreeMem(Buffer, Size); {Frees memory allocated to Buffer}
   result := windir;
end;


end.
